%%%%  Some examples of how to compute maximal surfaces in the indefinite
%%%%  Heisenberg group using the Matlab function iNil
%%%%  For more information about this function see, e.g. the tutorial
%%%%  on computing CMC surfaces here:
%%%%        http://davidbrander.org/ecmch_ksurf_tutorial.pdf
%%%%  The method for computing CMC surfaces is the same, only 
%%%%  the sym formula is different for maximal surfaces in indefinite Nil

%%%%  The examples and fingure numbers refer to the paper
%%%% "Maximal surfaces in the indefinite Heiseberg group" by David Brander and Shimpei Kobayashi.

%%%  Uncomment the sections of code below that you want to run

%%%    Examples using rectangular coordinates:
% % CMC Surface of revolution and associated maximal surface in Nil (Figure 1)
 a=1.2;
%% The potential in Example 3.9:
Y=@(r,t,h)[0 -a 0 a-1 0 0; 0 0 1-a 0 a 0];
%% We compute the surfaces associated, with initial condition identity over
%% a rectangular 37x81 grid centered at z=0,  approximating the loops as
%% polynomials in lambda of degree 8
[f,fcmc,N,fsph]=iNil(Y, eye(2), [0 2*pi/100 18 18], [0 2*pi/100,40,40], 8,1);
%% we can plot any of the surfaces just computed, with the function splot, e.g. plot the
%% spherical surface:

figure(); splot(fsph);

% % % we can plot the Gauss map N, plus two of the other surfaces, all with the
% % % same colormap, based on whether N takes values above or below the equator
% % % with "plotall".  E.g. plot N, the maximal surface f and the cmc surface
% % % fcmc, (showing 20 x 20 parameter curves):

plotall(N,f,fcmc,20,20);



%%% We compute part of the same surface with a rotated initial condition
%%% (Figure 1):

% Rot1=@(t)[cos(t/2),-1i*sin(t/2); -1i*sin(t/2), cos(t/2)];
% a=1.2;   Y=@(r,t,h)[0 -a 0 a-1 0 0; 0 0 1-a 0 a 0];
%  figure()
% [f,fcmc,N,fsph]=iNil(Y, Rot1(pi/2), [0 2*pi/150 60 60], [0 2*pi/150,5,25], 8,1);
% plotall(N,f,fcmc,20,20);






%%%%%%%%%%%%%    Singularity Examples   %%%%%%%%%%%%%%%%%%
%%%%%    swallowtail
% Y=@(r,t,h)[0 1 0 0 0 0; 0 0 -(1-1i-(r*exp(1i*t))*1i) 0 0 0];
% IC=(1/sqrt(2))*[1 1i;1i 1];
% [f,fcmc,N, fsph]=INilpolar(Y, IC, [0 0.008 40], [0 2*pi/200,200], 6,1);
% plotall(N,f,fcmc);
% 
% % %% same surface in rectangular coordinates
% Y2=@(z,h)[0 1 0 0 0 0; 0 0 -(1-1i-z*1i) 0 0 0];
% IC=(1/sqrt(2))*[1 1i;1i 1];
% figure()
% [f2,fcmc2,N2, fsph2]=iNil(Y2, IC, [0 0.008 30 30], [0 0.008 30 30], 6,1);
% plotall(N2,f2,fcmc2);



% %%% cuspidal crosscap (Example 4.8)
% Y=@(r,t,h)[0 1 0 0 0 0; 0 0 -(2-(1i*r*exp(1i*t))) 0 0 0];
% IC=(1/sqrt(2))*[1 1i;1i 1];
% [f,fcmc,N, fsph]=INilpolar(Y, IC, [0 0.015 30], [0 2*pi/200,200], 6,1);
% plotall(N,f,fcmc);


%%         Examples using rectangular coordinates -  iNil
%  swallowtail  (Figure 5)
% v=@(t)-1/sqrt(2);
% phi=@(t)t+pi/4;
% php=@(t)1;
% [X,IC]=singGCPNili(tp, phi,php);
% [f,fcmc,N, fsph]=iNil(X, IC, [0 sqrt(2)*2*pi/800 50 50], [0 0.015 40 40], 8,1);
% % plot f, the gauss map and the CMC surface using the same color map,
% % determined by whether the normal is above or below the equator
% plotall(N,f,fcmc);

%cuspidal cross-cap  (Figure 5)
% v=@(t)1;
% phi=@(t)t+pi/2;
% php=@(t)1;
% [X,IC]=singGCPNili(v, phi,php);
%  figure()
%  [f,fcmc,N, fsph]=iNil(X, IC, [0 sqrt(2)*2*pi/800 50 50], [0 0.015 40 40], 8,1);
% plotall(N,f,fcmc);
