function  f=splot(f,density,numx,numy,linewidth,scolor,edgecolor,redline)
%plots the surface f, which is the ouput of the function stcmc or
%omegatcmc.   

if nargin<2
    density=3;close all
    
end
f=interpf(f,density);
fdims=size(f);  xpoints=fdims(1)/3; ypoints=fdims(2);

if nargin<7
    edgecolor=[1,1,1];
end
if nargin<6
    scolor=[0.04,0.52,0.78];
end
if nargin<5
    linewidth=1;
end

if nargin<4
    numy=min(10,xpoints);
end
if nargin<3
    numx=min(10,ypoints);
end

colormap([scolor;edgecolor]);
C=zeros(xpoints,ypoints);
if numx>0
  if numx==1
    xcurves=1;
  else
    xstep=round((ypoints-1)/(numx-1));
    xcurves=[1,xstep+1:xstep:((numx-1)*xstep),ypoints];
  end
  for j=1:floor(numx/2)
      C(1:xpoints,xcurves(j):xcurves(j)+linewidth-1)=1;
  end
  for j=floor(numx/2)+1:numx
      C(1:xpoints,xcurves(j)-linewidth+1:xcurves(j))=1;
  end
end

if numy>0
  ystep=round((xpoints-1)/(numy-1));
  if numy==1
    ycurves=1;
  else
    ycurves=[1,ystep+1:ystep:((numy-1)*ystep),xpoints];
  end
  for j=1:floor(numy/2)
      C(ycurves(j):ycurves(j)+linewidth-1,:)=1;
  end
  for j=floor(numy/2)+1:numy
      C(ycurves(j)-linewidth+1:ycurves(j),:)=1;
  end
end

if nargin>7
      colormap([scolor;redline(3:5);edgecolor]);
      C(:,redline(1)-redline(2):redline(1)+redline(2))=0.5*ones(xpoints,1+2*redline(2));
end
    
surf(f(1:xpoints, :), f(xpoints+1: 2*xpoints, :),  f(2*xpoints+1: 3*xpoints, :),C, 'Clipping','off','EdgeAlpha',0,'FaceLighting','gouraud',...
    'DiffuseStrength',0.8,'SpecularExponent',20.0,'SpecularStrength',0.4,'AmbientStrength',0.35);
daspect([1 1 1])
  hold off
end

function  g=interpf(f,k)
%smooths the surface f=[X;Y;Z] by interpolating the points with cubic
%splines. k is the number of points to insert between the existing points

fdims=size(f);  xpoints=fdims(1)/3; ypoints=fdims(2);
X=f(1:xpoints,:);
Y=f(xpoints+1:2*xpoints,:);
Z=f(2*xpoints+1:3*xpoints,:);

[A,B]=meshgrid(0:1/(ypoints-1):1,0:1/(xpoints-1):1);
[Aq,Bq]=meshgrid(0:1/(k*(ypoints-1)):1,0:1/(k*(xpoints-1)):1);
Xq=interp2(A,B,X,Aq,Bq,'cubic');
Yq=interp2(A,B,Y,Aq,Bq,'cubic');
Zq=interp2(A,B,Z,Aq,Bq,'cubic');
g=[Xq;Yq;Zq];
end